SystemOrganization addCategory: #'Parasol-Core'!

TestResource subclass: #BPWebDriverManagerResource
	instanceVariableNames: 'drivers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPWebDriverManagerResource methodsFor: 'accessing' stamp: 'KrisGybels 6/29/2012 15:20'!
driverWithCapabilities: desiredCapabilities on: url

	drivers at: desiredCapabilities ifPresent: [ :cachedDriver |
		drivers removeKey: desiredCapabilities.
		[ cachedDriver get: url asString ] on: BPUnknownServerException do: [ :ex |
			self quitDriver: cachedDriver.
			^ self driverWithCapabilities: desiredCapabilities on: url.
		].
		^ cachedDriver.
	] ifAbsent: [
		^ ((BPRemoteWebDriver withCapabilities: desiredCapabilities)
			get: url asString;
			yourself).
	].
! !

!BPWebDriverManagerResource methodsFor: 'private' stamp: 'KrisGybels 6/29/2012 15:22'!
quitDriver: driver

	[ driver quit ] on: BPUnknownServerException do: [ :ex | ]! !

!BPWebDriverManagerResource methodsFor: 'accessing' stamp: 'KrisGybels 10/29/2013 17:45'!
quitOrCacheDriver: driver withCapabilities: capabilities

	drivers at: capabilities ifPresent: [ :cachedDriver |
		self quitDriver: driver.
	] ifAbsent: [
		[
			driver getWindowHandles size - 1 timesRepeat: [ driver close ].
			driver switchTo window: driver getWindowHandles anyOne.
			driver get: 'about:'. "<-- Reset the browser window to a blank page, might be executing scripts, timed refreshes or whatever in the background otherwise."
			driver getKeyboard sendKeys: (String with: BPKeys null). "<-- release any modifier keys."
		] on: BPUnknownServerException do: [ :ex | self quitDriver: driver. ^ self ].
		drivers at: capabilities put: driver.
	].! !

!BPWebDriverManagerResource methodsFor: 'running' stamp: 'KrisGybels 4/17/2012 14:37'!
setUp

	super setUp.
	drivers := Dictionary new.! !

!BPWebDriverManagerResource methodsFor: 'running' stamp: 'KrisGybels 6/29/2012 15:22'!
tearDown

	drivers do: [ :driver |
		[ driver quit ] on: BPUnsupportedCommandException do: [ :error | ].
	].
	super tearDown.
! !

TestCase subclass: #BPWebDriverTestCase
	instanceVariableNames: 'driver testComponent screenshotCounter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPWebDriverTestCase class methodsFor: 'accessing' stamp: 'KrisGybels 6/29/2012 15:13'!
resources

	^ super resources , (Array with: BPWebDriverManagerResource)! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'StephanEggermont 10/1/2012 17:40'!
baseURL

	^ (BPPlatform current urlFor: 'http://localhost/') port: BPPlatform current port; addPathSegment: self registrationName! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 4/12/2012 11:55'!
componentClass

	self subclassResponsibility.! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 4/11/2012 16:25'!
configureTestApp: testApp

	! !

!BPWebDriverTestCase methodsFor: 'as yet unclassified' stamp: 'topa 4/3/2013 17:09'!
defaultTimeout
	"Answer the default timeout to use for tests in this test case. The timeout is a value in seconds."

	^super defaultTimeout * 10! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 6/29/2012 15:17'!
desiredDriverBrowserCapabilities

	^ BPDesiredCapabilities firefox! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 4/11/2012 10:44'!
registrationName

	^ 'WDTest'! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 6/29/2012 15:16'!
setUp

	super setUp.
	self configureTestApp:
		(WAAdmin
			register: (BPClassInstantiationNotificationWrapper withRealClass: self componentClass instantiationNotificationBlock: [ :newInstance | testComponent := newInstance ])
			asApplicationAt: self registrationName).
	driver := BPWebDriverManagerResource current driverWithCapabilities: self desiredDriverBrowserCapabilities on: self baseURL.
	screenshotCounter := 1.
! !

!BPWebDriverTestCase methodsFor: 'misc.' stamp: 'KrisGybels 5/7/2012 16:28'!
takeScreenshot

	| screenshotData |
	screenshotData := driver getScreenshotAsByteArray.
	(StandardFileStream forceNewFileNamed: 'Screenshot ' , self class name , '>>' , self selector , ' ' , screenshotCounter asString , '.png')
		nextPutAll: screenshotData;
		close.
	screenshotCounter := screenshotCounter + 1.
	! !

!BPWebDriverTestCase methodsFor: 'running' stamp: 'KrisGybels 6/29/2012 15:23'!
tearDown
	
	driver ifNotNil: [
		BPWebDriverManagerResource current quitOrCacheDriver: driver withCapabilities: self desiredDriverBrowserCapabilities.
	].
	WAAdmin unregister: self registrationName.
	super tearDown.
! !

Object subclass: #BPObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

BPObject subclass: #BPAction
	instanceVariableNames: 'driver arguments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPAction methodsFor: 'misc' stamp: 'JohanBrichau 5/10/2012 13:52'!
actionPathSegment 
	self subclassResponsibility ! !

!BPAction methodsFor: 'private' stamp: 'JohanBrichau 5/10/2012 14:03'!
argumentAt: aString put: aValue 
	arguments at: aString put: aValue! !

!BPAction methodsFor: 'initialize-release' stamp: 'JohanBrichau 5/10/2012 14:05'!
initWithDriver: initializationDriver
	driver := initializationDriver.
! !

!BPAction methodsFor: 'initialize-release' stamp: 'JohanBrichau 5/10/2012 14:06'!
initialize 
	super initialize.
	arguments := Dictionary new.! !

!BPAction methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 17:32'!
perform

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Action.html#perform()
	"
	^ driver handleResponse: (driver httpPost: (driver baseSessionURL addPathSegment: self actionPathSegment)
		data: (BPPlatform current data: arguments asJson))
! !

BPAction subclass: #BPButtonReleaseAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPButtonReleaseAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/12/2012 11:37'!
driver: driver

	^ self new initWithDriver: driver! !

!BPButtonReleaseAction methodsFor: 'perform' stamp: 'StephanEggermont 10/1/2012 17:34'!
perform

	driver handleResponse:
		(driver httpPost: (driver baseSessionURL addPathSegment: 'buttonup')
			data: (BPPlatform current  data: (Dictionary new) asJson)).
! !

BPAction subclass: #BPClickAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPClickAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 14:06'!
driver: driver buttonNumber: buttonNumber

	^ self new driver: driver buttonNumber: buttonNumber! !

!BPClickAction methodsFor: 'perform' stamp: 'JohanBrichau 5/10/2012 14:08'!
actionPathSegment 
	^ 'click'! !

!BPClickAction methodsFor: 'initialize-release' stamp: 'JohanBrichau 5/10/2012 14:07'!
driver: initializationDriver buttonNumber: initializationButtonNumber

	self initWithDriver: initializationDriver.
	arguments at: 'button' put: initializationButtonNumber.! !

BPAction subclass: #BPClickAndHoldAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPClickAndHoldAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/12/2012 11:37'!
driver: driver

	^ self new initWithDriver: driver! !

!BPClickAndHoldAction methodsFor: 'perform' stamp: 'JohanBrichau 5/10/2012 14:34'!
actionPathSegment 
	^ 'buttondown'! !

BPAction subclass: #BPCompositeAction
	instanceVariableNames: 'actions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPCompositeAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 13:19'!
driver: driver

	^ self new initWithDriver: driver! !

!BPCompositeAction methodsFor: 'misc' stamp: 'KrisGybels 4/6/2012 13:15'!
addAction: action

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/CompositeAction.html#addAction(org.openqa.selenium.interactions.Action)
	"
	
	actions add: action.! !

!BPCompositeAction methodsFor: 'initialize-release' stamp: 'KrisGybels 4/6/2012 13:14'!
initialize

	super initialize.
	actions := OrderedCollection new.! !

!BPCompositeAction methodsFor: 'misc' stamp: 'KrisGybels 4/6/2012 13:16'!
perform

	actions do: [ :action |
		action perform.
	]! !

BPAction subclass: #BPDoubleClickAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPDoubleClickAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 13:26'!
driver: driver

	^ self new initWithDriver: driver! !

!BPDoubleClickAction methodsFor: 'perform' stamp: 'JohanBrichau 5/10/2012 14:34'!
actionPathSegment 
	^ 'doubleclick'! !

BPAction subclass: #BPMoveMouseAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPMoveMouseAction class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 13:23'!
driver: driver element: webElement

	^ self new initWithDriver: driver element: webElement! !

!BPMoveMouseAction class methodsFor: 'instance creation' stamp: 'JohanBrichau 3/3/2014 21:39'!
driver: driver offset: offset

	^ self new initWithDriver: driver offset: offset! !

!BPMoveMouseAction methodsFor: 'perform' stamp: 'JohanBrichau 5/10/2012 13:58'!
actionPathSegment 
	^ 'moveto'! !

!BPMoveMouseAction methodsFor: 'initialize-release' stamp: 'JohanBrichau 5/10/2012 14:10'!
initWithDriver: initializationDriver element: initializationWebElement

	self initWithDriver: initializationDriver.
	self argumentAt: 'element' put: initializationWebElement elementID.! !

!BPMoveMouseAction methodsFor: 'initialize-release' stamp: 'JohanBrichau 3/3/2014 21:39'!
initWithDriver: initializationDriver offset: offset

	self initWithDriver: initializationDriver.
	self xOffset: offset x yOffset: offset y! !

!BPMoveMouseAction methodsFor: 'accessing' stamp: 'JohanBrichau 5/10/2012 14:10'!
xOffset: x yOffset: y
	self argumentAt: 'xoffset' put: x.
	self argumentAt: 'yoffset' put: y.! !

BPObject subclass: #BPActions
	instanceVariableNames: 'driver action'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPActions class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 13:07'!
driver: driver

	^ self new initWithDriver: driver! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:14'!
build

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#build()
	"
	
	^ [ action ] ensure: [ action := BPCompositeAction driver: driver ]! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:14'!
clickAndHold

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#clickAndHold()
	"
	
	action addAction: (BPClickAndHoldAction driver: driver)
	! !

!BPActions methodsFor: 'misc' stamp: 'JohanBrichau 3/3/2014 20:16'!
clickAndHold: webElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#clickAndHold(org.openqa.selenium.WebElement)
	"
	
	self
		moveToElement: webElement;
		clickAndHold.! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:14'!
contextClick: webElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#contextClick(org.openqa.selenium.WebElement)
	"
	
	self moveToElement: webElement.
	action addAction: (BPClickAction driver: driver buttonNumber: 2).! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:15'!
doubleClick

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#doubleClick()
	"
	
	action addAction: (BPDoubleClickAction driver: driver)
	! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 4/6/2012 13:27'!
doubleClick: webElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#doubleClick()
	"
	
	self
		moveToElement: webElement;
		doubleClick.
! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 11:33'!
drag: sourceWebElement andDrop: targetWebElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#dragAndDrop(org.openqa.selenium.WebElement,%20org.openqa.selenium.WebElement)	
	"
	
	self
		clickAndHold: sourceWebElement;
		releaseButton: targetWebElement.! !

!BPActions methodsFor: 'misc' stamp: 'JohanBrichau 5/28/2013 15:08'!
drag: sourceWebElement andDropBy: aPoint

	"
http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#dragAndDropBy(org.openqa.selenium.WebElement,%20int,%20int)
	"
	
	self
		moveToElement: sourceWebElement offset: (1@1);
		clickAndHold;
		moveToElement: sourceWebElement offset: aPoint;
		releaseButton.! !

!BPActions methodsFor: 'initialize-release' stamp: 'KrisGybels 6/29/2012 15:14'!
initWithDriver: initializationDriver

	super initialize.
	driver := initializationDriver.
	action := BPCompositeAction driver: driver.! !

!BPActions methodsFor: 'misc' stamp: 'JohanBrichau 3/3/2014 21:38'!
moveByOffset: offset

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#moveByOffset(int, int)
	"
	
	action addAction: (BPMoveMouseAction driver: driver offset: offset)
	! !

!BPActions methodsFor: 'misc' stamp: 'JohanBrichau 3/3/2014 21:38'!
moveToElement: webElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#moveToElement(org.openqa.selenium.WebElement)
	"
	
	action addAction: (BPMoveMouseAction driver: driver element: webElement)
	! !

!BPActions methodsFor: 'misc' stamp: 'JohanBrichau 3/3/2014 21:38'!
moveToElement: webElement offset: aPoint

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#moveToElement(org.openqa.selenium.WebElement,%20int,%20int)
	"
	
	action addAction: ((BPMoveMouseAction driver: driver element: webElement) xOffset: aPoint x yOffset: aPoint y; yourself)
	! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 12:06'!
perform

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#perform()
	"

	self build perform
! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:14'!
releaseButton

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#release()
	"
	
	action addAction: (BPButtonReleaseAction driver: driver)
! !

!BPActions methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 11:32'!
releaseButton: webElement

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/interactions/Actions.html#release(org.openqa.selenium.WebElement)
	"
	
	self
		moveToElement: webElement;
		releaseButton.! !

BPObject subclass: #BPClassInstantiationNotificationWrapper
	instanceVariableNames: 'realClass instantiationNotificationBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPClassInstantiationNotificationWrapper class methodsFor: 'instance creation' stamp: 'KrisGybels 4/12/2012 21:51'!
withRealClass: realClass instantiationNotificationBlock: instantiationNotificationBlock

	^ self basicNew initWithRealClass: realClass instantiationNotificationBlock: instantiationNotificationBlock! !

!BPClassInstantiationNotificationWrapper methodsFor: 'initialize-release' stamp: 'KrisGybels 4/12/2012 21:53'!
initWithRealClass: initializationRealClass instantiationNotificationBlock: initializationInstantiationNotificationBlock

	self initialize.
	realClass := initializationRealClass.
	instantiationNotificationBlock := initializationInstantiationNotificationBlock.! !

!BPClassInstantiationNotificationWrapper methodsFor: 'instance creation' stamp: 'KrisGybels 4/12/2012 21:56'!
new

	| newInstance |
	newInstance := realClass new.
	instantiationNotificationBlock value: newInstance.
	^ newInstance! !

BPObject subclass: #BPDesiredCapabilities
	instanceVariableNames: 'dict'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPDesiredCapabilities class methodsFor: 'predefined' stamp: 'KrisGybels 4/10/2012 09:09'!
chrome

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#chrome()
	"

	^ self new
		setCapability: 'browserName' to: 'chrome';
		yourself
	! !

!BPDesiredCapabilities class methodsFor: 'predefined' stamp: 'KrisGybels 4/10/2012 09:16'!
firefox

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#firefox()
	"

	^ self new
		setCapability: 'browserName' to: 'firefox';
		yourself
	! !

!BPDesiredCapabilities class methodsFor: 'predefined' stamp: 'KrisGybels 4/13/2012 08:08'!
htmlUnit

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#htmlUnit()
	"

	^ self new
		setCapability: 'browserName' to: 'htmlunit';
		yourself
! !

!BPDesiredCapabilities class methodsFor: 'predefined' stamp: 'KrisGybels 10/25/2013 10:18'!
safari

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#safari()
	"

	^ self new
		setCapability: 'browserName' to: 'safari';
		yourself
	! !

!BPDesiredCapabilities methodsFor: 'comparing' stamp: 'KrisGybels 4/17/2012 14:34'!
= other

	^ (self class = other class) and: [
		self asDictionary = other asDictionary.
	].! !

!BPDesiredCapabilities methodsFor: 'converting' stamp: 'KrisGybels 4/10/2012 09:28'!
asDictionary

	^ dict! !

!BPDesiredCapabilities methodsFor: 'misc' stamp: 'KrisGybels 4/10/2012 09:07'!
getCapability: capabilityName

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#getCapability(java.lang.String)
	"
	
	^ dict at: capabilityName! !

!BPDesiredCapabilities methodsFor: 'comparing' stamp: 'KrisGybels 4/17/2012 14:34'!
hash

	^ self asDictionary hash! !

!BPDesiredCapabilities methodsFor: 'initialize-release' stamp: 'KrisGybels 4/10/2012 09:03'!
initialize

	super initialize.
	dict := Dictionary new.! !

!BPDesiredCapabilities methodsFor: 'misc' stamp: 'KrisGybels 4/10/2012 09:05'!
setCapability: capabilityName to: capabilityValue

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/DesiredCapabilities.html#setCapability(java.lang.String,%20java.lang.String)
	"
	
	dict at: capabilityName put: capabilityValue! !

BPObject subclass: #BPKeyboard
	instanceVariableNames: 'driver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPKeyboard class methodsFor: 'instance creation' stamp: 'KrisGybels 4/10/2012 17:06'!
withDriver: driver

	^ self basicNew initWithDriver: driver! !

!BPKeyboard methodsFor: 'initialize-release' stamp: 'KrisGybels 4/10/2012 17:05'!
initWithDriver: initializationDriver

	super initialize.
	driver := initializationDriver.
! !

!BPKeyboard methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 17:35'!
sendKeys: keyString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keyboard.html#sendKeys(java.lang.CharSequence...)
	"
	
	| keyArray |
	self flag: 'This may need to take something other than a string, to be able to send special key presses (like shift, command etc.)'.
	
	keyArray := keyString collect: [ :char | char asString ] as: Array.
	driver handleResponse:
		(driver httpPost: (driver baseSessionURL addPathSegment: 'keys')
			data: (BPPlatform current data: (Dictionary new at: 'value' put: keyArray; yourself) asJson))
! !

BPObject subclass: #BPKeys
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:18'!
add

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ADD
	"
	
	^ Character codePoint: 16rE025
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:25'!
alt

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ALT
	"
	
	^ Character codePoint: 16rE00A! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:30'!
arrowDown

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ARROW_DOWN
	"
	
	^ self down
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:28'!
arrowLeft

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ARROW_LEFT
	"
	
	^ self left! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:30'!
arrowRight

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ARROW_RIGHT
	"
	
	^ self right
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:29'!
arrowUp

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ARROW_UP
	"
	
	^ self up! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:23'!
backSpace

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#BACK_SPACE
	"
	
	^ Character codePoint: 16rE003
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:22'!
cancel

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#CANCEL
	"
	
	^ Character codePoint: 16rE001
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:23'!
clear

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#CLEAR
	"
	
	^ Character codePoint: 16rE005
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/17/2012 11:24'!
command

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#COMMAND
	"
	
	^ Character codePoint: 16rE03D
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:25'!
control

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#CONTROL
	"
	
	^ Character codePoint: 16rE009
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:19'!
decimal

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#DECIMAL
	"
	
	^ Character codePoint: 16rE028
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:31'!
delete

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#DELETE
	"
	
	^ Character codePoint: 16rE017
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:19'!
divide

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#DIVIDE
	"
	
	^ Character codePoint: 16rE029
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:30'!
down

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#DOWN
	"
	
	^ Character codePoint: 16rE015
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:27'!
end

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#END
	"
	
	^ Character codePoint: 16rE010
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:23'!
enter

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ENTER
	"
	
	^ Character codePoint: 16rE007
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:32'!
equals

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#EQUALS
	"
	
	^ Character codePoint: 16rE019! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:26'!
escape

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#ESCAPE
	"
	
	^ Character codePoint: 16rE00C
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:19'!
f1

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F1
	"
	
	^ Character codePoint: 16rE031
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f10

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F10
	"
	
	^ Character codePoint: 16rE03A
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:21'!
f11

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F11
	"
	
	^ Character codePoint: 16rE03B
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:21'!
f12

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F12
	"
	
	^ Character codePoint: 16rE03C
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f2

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F2
	"
	
	^ Character codePoint: 16rE032
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f3

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F3
	"
	
	^ Character codePoint: 16rE033
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f4

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F4
	"
	
	^ Character codePoint: 16rE034
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f5

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F5
	"
	
	^ Character codePoint: 16rE035
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f6

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F6
	"
	
	^ Character codePoint: 16rE036
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f7

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F7
	"
	
	^ Character codePoint: 16rE037
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f8

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F8
	"
	
	^ Character codePoint: 16rE038
! !

!BPKeys class methodsFor: 'function keys' stamp: 'KrisGybels 4/18/2012 10:20'!
f9

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#F9
	"
	
	^ Character codePoint: 16rE039
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:22'!
help

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#HELP
	"
	
	^ Character codePoint: 16rE002
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:27'!
home

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#HOME
	"
	
	^ Character codePoint: 16rE011
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:31'!
insert

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#INSERT
	"
	
	^ Character codePoint: 16rE016
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:28'!
left

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#LEFT
	"
	
	^ Character codePoint: 16rE012
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:25'!
leftAlt

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#LEFT_ALT
	"
	
	^ self alt! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:25'!
leftControl

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#LEFT_CONTROL
	"
	
	^ self control
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:24'!
leftShift

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#LEFT_SHIFT
	"
	
	^ self shift
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:17'!
multiply

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#MULTIPLY
	"
	
	^ Character codePoint: 16rE024
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/17/2012 11:23'!
null

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NULL
	"
	
	^ Character codePoint: 16rE000
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad0

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD0
	"

	^ Character codePoint: 16rE01A
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad1

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD1
	"

	^ Character codePoint: 16rE01B
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad2

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD2
	"

	^ Character codePoint: 16rE01C
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad3

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD3
	"

	^ Character codePoint: 16rE01D
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad4

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD4
	"

	^ Character codePoint: 16rE01E
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad5

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD5
	"

	^ Character codePoint: 16rE01F
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:16'!
numpad6

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD6
	"

	^ Character codePoint: 16rE020
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:17'!
numpad7

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD7
	"

	^ Character codePoint: 16rE021
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:17'!
numpad8

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD8
	"

	^ Character codePoint: 16rE022
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:17'!
numpad9

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#NUMPAD9
	"

	^ Character codePoint: 16rE023
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/12/2012 12:20'!
pageDown

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#PAGE_DOWN
	"
	
	^ Character codePoint: 16rE00F
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:27'!
pageUp

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#PAGE_UP
	"
	
	^ Character codePoint: 16rE00E
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:26'!
pause

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#PAUSE
	"
	
	^ Character codePoint: 16rE00B
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/15/2012 16:29'!
return

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#RETURN
	"
	
	^ Character codePoint: 16rE006
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 2/6/2013 13:31'!
right

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#RIGHT
	"
	
	^ Character codePoint: 16rE014
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:31'!
semicolon

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#SEMICOLON
	"
	
	^ Character codePoint: 16rE018! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:18'!
separator

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#SEPARATOR
	"
	
	^ Character codePoint: 16rE026
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:24'!
shift

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#SHIFT
	"
	
	^ Character codePoint: 16rE008
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:26'!
space

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#SPACE
	"
	
	^ Character codePoint: 16rE00D
! !

!BPKeys class methodsFor: 'number pad keys' stamp: 'KrisGybels 4/18/2012 10:18'!
subtract

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#SUBTRACT
	"
	
	^ Character codePoint: 16rE027
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:23'!
tab

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#TAB
	"
	
	^ Character codePoint: 16rE004
! !

!BPKeys class methodsFor: 'misc. keys' stamp: 'KrisGybels 4/18/2012 10:28'!
up

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/Keys.html#UP
	"
	
	^ Character codePoint: 16rE013
! !

!BPObject class methodsFor: 'instance creation' stamp: 'StephanEggermont 9/28/2012 16:49'!
new
	^ self basicNew initialize! !

!BPObject methodsFor: 'initialize-release' stamp: 'StephanEggermont 9/28/2012 16:47'!
initialize
! !

BPObject subclass: #BPOptions
	instanceVariableNames: 'driver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPOptions class methodsFor: 'instance creation' stamp: 'KrisGybels 11/6/2012 10:21'!
withDriver: driver

	^ self new initWithDriver: driver! !

!BPOptions methodsFor: 'initialize-release' stamp: 'KrisGybels 11/6/2012 10:22'!
initWithDriver: initialDriver

	self initialize.
	driver := initialDriver.! !

!BPOptions methodsFor: 'misc' stamp: 'KrisGybels 9/8/2013 20:22'!
timeouts

	"
		http://selenium.googlecode.com/git/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.RemoteWebDriverOptions.html#timeouts()
	"
	
	^ BPTimeouts withDriver: driver! !

!BPOptions methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 10:30'!
window

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.Options.html#window()
	"
	
	self flag: 'It is not clear in the Java documentation what is meant by the current window, current at the time of calling this method, or current at the time you are interacting with the window object? Note that in the wire protocol POST requests on /session/:sessionId/window/:windowHandle/size are allowed to use "current" for the windowHandle parameter'.
	^ BPWindow withDriver: driver handle: driver getWindowHandle! !

BPObject subclass: #BPPlatform
	instanceVariableNames: 'name httpEntityClass mimeTypeClass httpClientClass urlClass port'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

BPPlatform class
	instanceVariableNames: 'current platforms'!

BPPlatform class
	instanceVariableNames: 'current platforms'!

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:00'!
add: aPlatform
	aPlatform check.
	
	self platforms at: aPlatform name put: aPlatform ! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:01'!
current
	^ current! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:01'!
numberOfPlatforms
	^ self  platforms size ! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:01'!
platforms
	^ platforms ifNil: [ platforms := Dictionary new ]! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:01'!
removeNamed: aName
	self platforms removeKey: aName! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:02'!
removeNamed: aName ifAbsent: aBlock
	self platforms removeKey: aName ifAbsent: aBlock! !

!BPPlatform class methodsFor: 'as yet unclassified' stamp: 'StephanEggermont 9/28/2012 17:02'!
setCurrent: aPlatformName
	current := self platforms at: aPlatformName! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 9/28/2012 17:04'!
check
	self assert: [ self name class == 'abc' class ] description: 'A platform name should be a string'.
"	self assert: [ self canvasClass superclass ==  ROAbstractCanvas ] description: 'A platform canvas should be a subclass of ROAbstractCanvas'.
	self assert: [ self fontOrganizerClass superclass ==  ROFontOrganizer ] description: 'A platform font organizer should be a subclass of ROFontOrganizerMorphic'.
	self assert: [ self widgetFactory superclass ==  RONativeWidgetFactory  ] description: 'A platform widget organizer should be a subclass of ROFontOrganizerMorphic'.
	self assert: [ self timeOrganizerClass superclass ==  ROTimeOrganizer  ] description: 'A platform time organizer should be a subclass of ROTimeOrganizer'.
	self assert: [ self hostVisualElement notNil ] description: 'You need to provide a host visual element (a Morph or a Visual)'.
"! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 17:32'!
data: aDictionary 
	^self httpEntityClass with: aDictionary type: ((self mimeTypeClass main: 'application' sub: 'json') setCharSetUTF8; yourself)! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 17:32'!
data: aDictionary type: aSymbol
	^self httpEntityClass with: aDictionary type: ((self mimeTypeClass main: 'application' sub: 'json') setCharSetUTF8; yourself)! !

!BPPlatform methodsFor: 'accessing-private' stamp: 'topa 4/3/2013 16:42'!
httpClient

	"For compatibility with an older version of Zinc:"
	Smalltalk at: #ZnNeoClient ifPresent: [ :class | ^ class new beOneShot; yourself ].
	^ BPPlatform current httpClientClass new beOneShot; followRedirects: false; yourself.! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:12'!
httpClientClass
	^httpClientClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:12'!
httpClientClass: aClass
	httpClientClass:= aClass! !

!BPPlatform methodsFor: 'performing' stamp: 'topa 4/3/2013 16:39'!
httpDelete: url

	^ self httpClient url: url; delete; response! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 14:41'!
httpEntityClass
	^httpEntityClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 14:42'!
httpEntityClass: aClass
	httpEntityClass := aClass! !

!BPPlatform methodsFor: 'performing' stamp: 'topa 4/3/2013 16:39'!
httpGet: url

	^ self httpClient url: url; get; response! !

!BPPlatform methodsFor: 'performing' stamp: 'topa 4/3/2013 16:39'!
httpPost: url data: data

	^ self httpClient url: url; entity: data; post; response
! !

!BPPlatform methodsFor: 'performing' stamp: 'topa 4/3/2013 16:39'!
httpPost: url data: data timeout: seconds

	^ self httpClient timeout: seconds; url: url; entity: data; post; response
! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:02'!
mimeTypeClass
	^mimeTypeClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:03'!
mimeTypeClass: aClass
	mimeTypeClass := aClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 9/28/2012 17:02'!
name
	^ name! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 17:42'!
port
	^port! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 17:42'!
port: aPort
	port:= aPort! !

!BPPlatform methodsFor: 'testing' stamp: 'topa 4/3/2013 17:37'!
responseHasContent: aResponse

	^ aResponse status ~= 204! !

!BPPlatform methodsFor: 'converting' stamp: 'KrisGybels 8/14/2013 14:13'!
sessionIdFromResponse: response

	((response status = 302) | (response status = 303)) ifTrue: [
		^ (self urlClass fromString: (response headers at: 'Location')) lastPathSegment
	].
	(response status = 200) ifTrue: [
		^ (JSJsonParser parse: response contents withoutTrailingZeroes) at: 'sessionId'
	].
	self error: 'Unexpected response status code ' , response status asString , ' while creating web driver session.'! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:17'!
urlClass
	^urlClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 15:17'!
urlClass: aClass
	urlClass:= aClass! !

!BPPlatform methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 17:42'!
urlFor: aString! !

BPObject subclass: #BPRemoteWebDriver
	instanceVariableNames: 'sessionID'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

BPRemoteWebDriver class
	instanceVariableNames: 'serverHost serverPort'!

!BPRemoteWebDriver commentStamp: 'topa 4/4/2013 10:47' prior: 0!
An XXRemoteWebDriver represents the client-side object-oriented interface to a single session on a RemoteWebDriverServer [1]. It presents an interface similar to that of its Java counterpart [2,3]. It communicates with the RemoteWebDriverServer through the WebDriver wire protocol [4].

	[1]: http://code.google.com/p/selenium/wiki/RemoteWebDriverServer
	[2]: http://selenium.googlecode.com/svn/trunk/docs/api/java/index.html
	[3]: http://code.google.com/p/selenium/source/browse/trunk/java/client/src/org/openqa/selenium/remote/RemoteWebDriver.java
	[4]: http://code.google.com/p/selenium/wiki/JsonWireProtocol
!

BPRemoteWebDriver class
	instanceVariableNames: 'serverHost serverPort'!

!BPRemoteWebDriver class methodsFor: 'instance creation' stamp: 'KrisGybels 6/29/2012 15:17'!
new

	^ self withCapabilities: BPDesiredCapabilities firefox! !

!BPRemoteWebDriver class methodsFor: 'configuration' stamp: 'KrisGybels 7/2/2012 12:20'!
serverHost

	^ serverHost ifNil: [ '127.0.0.1' ]! !

!BPRemoteWebDriver class methodsFor: 'configuration' stamp: 'KrisGybels 7/2/2012 12:19'!
serverHost: hostName

	serverHost := hostName! !

!BPRemoteWebDriver class methodsFor: 'configuration' stamp: 'KrisGybels 7/2/2012 12:20'!
serverPort

	^ serverPort ifNil: [ 4444 ]! !

!BPRemoteWebDriver class methodsFor: 'configuration' stamp: 'KrisGybels 7/2/2012 12:19'!
serverPort: portNumber

	serverPort := portNumber! !

!BPRemoteWebDriver class methodsFor: 'instance creation' stamp: 'KrisGybels 4/10/2012 09:27'!
withCapabilities: capabilities

	^ self basicNew initWithCapabilities: capabilities! !

!BPRemoteWebDriver methodsFor: 'accessing' stamp: 'StephanEggermont 10/1/2012 18:02'!
baseDriverURL

	^ BPPlatform current urlClass new
		scheme: #http;
		host: self class serverHost;
		port: self class serverPort;
		segments: (OrderedCollection with: 'wd' with: 'hub');
		query: nil;
		fragment: nil;
		yourself.! !

!BPRemoteWebDriver methodsFor: 'accessing' stamp: 'KrisGybels 4/10/2012 08:32'!
baseSessionURL

	^ self baseDriverURL addPathSegment: 'session'; addPathSegment: sessionID; yourself! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:55'!
close

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#close()
	"

	self handleResponse: (self httpDelete: (self baseSessionURL addPathSegment: 'window'))
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 18:02'!
executeScript: scriptString with: arguments

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#executeScript(java.lang.String,%20java.lang.Object...)
	"
	
	self flag: 'Check whether this implementation matches the description of the original Java method'.
	self flag: 'One point definitely missing is that this does not yet handle converting an {ELEMENT: ....} thingy back to a WebElement.'.

	^ self handleResponse:
			(self httpPost: (self baseSessionURL addPathSegment: 'execute')
				data: (BPPlatform current data: (Dictionary new at: 'script' put: scriptString; at: 'args' put: arguments; yourself) asJson))
		onSuccess: [ :result |
			result at: 'value'.
		].! !

!BPRemoteWebDriver methodsFor: 'private' stamp: 'StephanEggermont 10/1/2012 18:57'!
findElementBy: selectorString with: valueString

	^ self handleResponse:
			(self httpPost: (self baseSessionURL addPathSegment: 'element')
				data: (BPPlatform current data: (Dictionary new at: 'using' put: selectorString; at: 'value' put: valueString; yourself) asJson))
		onSuccess: [ :result |
			BPWebElement driver: self elementID: ((result at: 'value') at: 'ELEMENT')
		].! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 19:29'!
findElementByCSSSelector: cssSelectorString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByCssSelector(java.lang.String)
	"
	
	^ self findElementBy: 'css selector' with: cssSelectorString

	
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'JohanBrichau 5/18/2012 17:03'!
findElementByClassName: nameString

	"
http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByClassName(java.lang.String)
	"
	
	^ self findElementBy: 'class name' with: nameString! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 19:28'!
findElementByID: idString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementById(java.lang.String)
	"
	
	^ self findElementBy: 'id' with: idString! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 20:19'!
findElementByLinkText: textString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByLinkText(java.lang.String)
	"

	^ self findElementBy: 'link text' with: textString
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 19:28'!
findElementByName: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByName(java.lang.String)
	"

	^ self findElementBy: 'name' with: nameString

! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 20:20'!
findElementByPartialLinkText: textString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByPartialLinkText(java.lang.String)
	"

	^ self findElementBy: 'partial link text' with: textString
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 19:49'!
findElementByTagName: tagNameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByTagName(java.lang.String)
	"

	^ self findElementBy: 'tag name' with: tagNameString
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 4/12/2012 19:55'!
findElementByXPath: xpathString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementByXPath(java.lang.String)
	"

	^ self findElementBy: 'xpath' with: xpathString
! !

!BPRemoteWebDriver methodsFor: 'private' stamp: 'StephanEggermont 10/1/2012 19:00'!
findElementsBy: selectorString with: valueString

	^ self handleResponse:
			(self httpPost: (self baseSessionURL addPathSegment: 'elements')
				data: (BPPlatform current data: (Dictionary new at: 'using' put: selectorString; at: 'value' put: valueString; yourself) asJson))
		onSuccess: [ :result |
			(result at: 'value') collect: [ :e | BPWebElement driver: self elementID: (e at: 'ELEMENT')]
		]. ! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'JohanBrichau 5/18/2012 17:00'!
findElementsByCSSSelector: cssSelectorString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementsByCssSelector(java.lang.String)
	"
	
	^ self findElementsBy: 'css selector' with: cssSelectorString

	
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'JohanBrichau 5/18/2012 17:03'!
findElementsByClassName: nameString

	"
http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementsByClassName(java.lang.String)
	"
	
	^ self findElementsBy: 'class name' with: nameString! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'AndyKellens 2/13/2013 15:55'!
findElementsByPartialLinkText: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'partial link text' with: nameString
! !

!BPRemoteWebDriver methodsFor: 'private' stamp: 'ThomasCleenewerck 7/6/2012 17:48'!
findElementsByTagName: tagNameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementsByTagName(java.lang.String)
	"

	^ self findElementsBy: 'tag name' with: tagNameString
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 19:40'!
findElementsByXPath: tagNameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#findElementsByXPath(java.lang.String)
	"

	^ self findElementsBy: 'xpath' with: tagNameString! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 19:00'!
get: urlString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#get(java.lang.String)
	"

	self handleResponse:
		(self httpPost: (self baseSessionURL addPathSegment: 'url')
			data: (BPPlatform current data: (Dictionary new at: 'url' put: urlString; yourself) asJson))


! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:19'!
getKeyboard

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.html#getKeyboard()
	"
	
	^ BPKeyboard withDriver: self! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:56'!
getPageSource

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#getPageSource()
	"
	
	^ self handleResponse: (self httpGet: (self baseSessionURL addPathSegment: 'source'))
		onSuccess: [ :result | result at: 'value' ]
	! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:45'!
getScreenshotAsByteArray

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/TakesScreenshot.html#getScreenshotAs(org.openqa.selenium.OutputType)
	"
	
	^ self handleResponse: (self httpGet: (self baseSessionURL addPathSegment: 'screenshot'))
		onSuccess: [ :result | (result at: 'value') base64Decoded asByteArray ]
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:45'!
getTitle

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#getTitle()
	"

	^ self handleResponse: (self httpGet: (self baseSessionURL addPathSegment: 'title'))
		onSuccess: [ :result | result at: 'value' ]! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:45'!
getWindowHandle

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#getWindowHandle()
	"
	
	^  self handleResponse: (self httpGet: (self baseSessionURL addPathSegment: 'window_handle'))
		onSuccess: [ :result | result at: 'value' ]! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:45'!
getWindowHandles

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#getWindowHandles()
	"
	
	^  self handleResponse: (self httpGet: (self baseSessionURL addPathSegment: 'window_handles'))
		onSuccess: [ :result | result at: 'value' ]! !

!BPRemoteWebDriver methodsFor: 'private' stamp: 'KrisGybels 6/18/2014 16:21'!
handleResponse: response

	(BPPlatform current responseHasContent: response) ifTrue: [
		self handleResponse: response onSuccess: [ :result | (result at: 'value') ifNotNil: [ self error: 'Value unexpectedly not JSON null' ] ].
	]
! !

!BPRemoteWebDriver methodsFor: 'private' stamp: 'KrisGybels 7/12/2012 07:16'!
handleResponse: response onSuccess: successBlock

	| result status |
	(response status = 404) ifTrue: [ BPUnsupportedCommandException signal ].
	result := JSJsonParser parse: response contents withoutTrailingZeroes.
	status := result at: 'status'.
	status = 0 ifTrue: [
		^ successBlock value: result.
	].
	status = 7 ifTrue: [
		BPNoSuchElementException signal: 'No such element exception'
	].
	status = 10 ifTrue: [
		BPStaleElementReferenceException signal: 'Stale element reference exception'
	].
	status = 11 ifTrue: [
		BPElementNotVisibleException signal: 'Element is not visible exception'
	].
	status = 13 ifTrue: [
		BPUnknownServerException signal: 'Unknown server exception'
	].
	status = 32 ifTrue: [
		BPInvalidSelectorException signal: 'Invalid selector exception'
	].
	self error: 'Unknown result status'.
! !

!BPRemoteWebDriver methodsFor: 'private-http' stamp: 'topa 4/3/2013 16:40'!
httpDelete: url

	^ BPPlatform current  httpDelete: url! !

!BPRemoteWebDriver methodsFor: 'private-http' stamp: 'topa 4/3/2013 16:40'!
httpGet: url

	^ BPPlatform current httpGet: url! !

!BPRemoteWebDriver methodsFor: 'private-http' stamp: 'topa 4/3/2013 16:41'!
httpPost: url data: data

	^ BPPlatform current httpPost: url data: data! !

!BPRemoteWebDriver methodsFor: 'private-http' stamp: 'topa 4/3/2013 16:41'!
httpPost: url data: data timeout: seconds

	^ BPPlatform current httpPost: url data: data timeout: seconds! !

!BPRemoteWebDriver methodsFor: 'initialize-release' stamp: 'topa 4/3/2013 17:13'!
initWithCapabilities: capabilities

	| response |
	self initialize.
	
	response :=
		self httpPost: (self baseDriverURL addPathSegment: 'session')
				data: (BPPlatform current data: (Dictionary new at: 'desiredCapabilities' put: capabilities asDictionary; yourself) asJson)
				timeout: 30.
	sessionID := BPPlatform current sessionIdFromResponse: response! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 10:25'!
manage

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#manage()
	"
	
	^ BPOptions withDriver: self! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:46'!
quit

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#quit()
	"

	self handleResponse: (self httpDelete: self baseSessionURL)
! !

!BPRemoteWebDriver methodsFor: 'misc' stamp: 'KrisGybels 6/29/2012 15:21'!
switchTo

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.html#switchTo()
	"
	
	^ BPTargetLocator withDriver: self! !

BPObject subclass: #BPSelect
	instanceVariableNames: 'element'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPSelect class methodsFor: 'instance creation' stamp: 'KrisGybels 5/30/2012 15:56'!
on: element

	^ self basicNew initWithElement: element! !

!BPSelect methodsFor: 'initialize-release' stamp: 'KrisGybels 5/30/2012 16:20'!
initWithElement: initializationElement

	self flag: 'This is supposed throw an exception if the element''s tag is not SELECT, http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/support/ui/Select.html#Select(org.openqa.selenium.WebElement)'.
	
	self initialize.
	element := initializationElement.! !

!BPSelect methodsFor: 'misc.' stamp: 'KrisGybels 5/30/2012 16:07'!
selectByValue: valueString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/support/ui/Select.html#selectByValue(java.lang.String)
	"

	| options |
	
	self flag: 'This implementation is not complete, check the Java version'.
	
	options := (element findElementsByXPath: './/option[@value=''' , valueString , ''']').
	options do: [ :option |
		option click.
	].! !

!BPSelect methodsFor: 'misc.' stamp: 'KrisGybels 10/9/2012 11:01'!
selectByVisibleText: visibleText

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/support/ui/Select.html#selectByVisibleText(java.lang.String)
	"

	| options |
	
	self flag: 'This implementation is not complete, check the Java version'.
	
	options := (element findElementsByXPath: './/option[normalize-space(.)=''' , visibleText , ''']').
	options do: [ :option |
		option click.
	].! !

BPObject subclass: #BPTargetLocator
	instanceVariableNames: 'driver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPTargetLocator class methodsFor: 'instance creation' stamp: 'KrisGybels 5/23/2012 16:35'!
withDriver: driver

	^ self basicNew initWithDriver: driver! !

!BPTargetLocator methodsFor: 'initialize-release' stamp: 'KrisGybels 5/23/2012 16:35'!
initWithDriver: initializationDriver

	super initialize.
	driver := initializationDriver.
! !

!BPTargetLocator methodsFor: 'misc.' stamp: 'StephanEggermont 10/1/2012 17:37'!
window: windowHandle

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.TargetLocator.html#window(java.lang.String)
	"

	driver handleResponse:
		(driver httpPost: (driver baseSessionURL addPathSegment: 'window')
			data: (BPPlatform current data: (Dictionary new at: 'name' put: windowHandle; yourself) asJson))
! !

BPObject subclass: #BPTimeouts
	instanceVariableNames: 'driver'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPTimeouts class methodsFor: 'instance creation' stamp: 'KrisGybels 9/8/2013 20:13'!
withDriver: driver

	^ self new initWithDriver: driver! !

!BPTimeouts methodsFor: 'accessing' stamp: 'KrisGybels 9/8/2013 20:24'!
implicitlyWait: duration

	"
		http://selenium.googlecode.com/git/docs/api/java/org/openqa/selenium/remote/RemoteWebDriver.RemoteWebDriverOptions.RemoteTimeouts.html#implicitlyWait(long,%20java.util.concurrent.TimeUnit)
	"
	
	driver handleResponse:
		(driver httpPost: (driver baseSessionURL addPathSegment: 'timeouts'; addPathSegment: 'implicit_wait')
			data: (BPPlatform current data: (Dictionary new at: 'ms' put: duration asMilliseconds; yourself) asJson))! !

!BPTimeouts methodsFor: 'initialize-release' stamp: 'KrisGybels 9/8/2013 20:13'!
initWithDriver: initDriver

	driver := initDriver.! !

BPObject subclass: #BPWebElement
	instanceVariableNames: 'driver elementID'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPWebElement class methodsFor: 'instance creation' stamp: 'KrisGybels 4/6/2012 12:31'!
driver: driver elementID: elementID

	^ self new initWithDriver: driver elementID: elementID! !

!BPWebElement methodsFor: 'comparing' stamp: 'KrisGybels 7/4/2012 10:57'!
= other

	^ (other isKindOf: BPWebElement) and: [
		driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'equals'; addPathSegment: other elementID))
			onSuccess: [ :result | result at: 'value' ]
	]! !

!BPWebElement methodsFor: 'accessing' stamp: 'KrisGybels 4/6/2012 15:27'!
baseElementURL

	^ driver baseSessionURL addPathSegment: 'element'; addPathSegment: elementID! !

!BPWebElement methodsFor: 'misc' stamp: 'StephanEggermont 10/1/2012 17:43'!
clear

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#clear()
	"

	driver handleResponse:
		(driver httpPost: (self baseElementURL addPathSegment: 'clear')
			data: (BPPlatform current data: (Dictionary new) asJson ))
! !

!BPWebElement methodsFor: 'events' stamp: 'StephanEggermont 10/1/2012 17:43'!
click

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#click()
	"
	
	driver handleResponse:
		(driver httpPost: (self baseElementURL addPathSegment: 'click')
			data: (BPPlatform current data: (Dictionary new) asJson))

! !

!BPWebElement methodsFor: 'accessing' stamp: 'KrisGybels 4/6/2012 13:29'!
elementID

	^ elementID! !

!BPWebElement methodsFor: 'private' stamp: 'StephanEggermont 10/1/2012 17:44'!
findElementBy: selectorString with: valueString

	^ driver handleResponse:
			(driver httpPost: (self baseElementURL addPathSegment: 'element')
				data: (BPPlatform current data: (Dictionary new at: 'using' put: selectorString; at: 'value' put: valueString; yourself) asJson))
		onSuccess: [ :result |
			BPWebElement driver: driver elementID: ((result at: 'value') at: 'ELEMENT')
		].! !

!BPWebElement methodsFor: 'misc' stamp: 'ThomasCleenewerck 7/6/2012 17:48'!
findElementByCSSSelector: cssSelectorString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementBy: 'css selector' with: cssSelectorString! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 4/15/2012 16:08'!
findElementByClassName: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElement(org.openqa.selenium.By)
	"
	
	^ self findElementBy: 'class name' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'JohanBrichau 8/14/2012 19:57'!
findElementByPartialLinkText: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElement(org.openqa.selenium.By)
	"
	
	^ self findElementBy: 'partial link text' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 4/15/2012 16:18'!
findElementByTagName: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElement(org.openqa.selenium.By)
	"
	
	^ self findElementBy: 'tag name' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 10/9/2012 11:18'!
findElementByXPath: xpathString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElement(org.openqa.selenium.By)
	"
	
	^ self findElementBy: 'xpath' with: xpathString
! !

!BPWebElement methodsFor: 'private' stamp: 'StephanEggermont 10/1/2012 17:44'!
findElementsBy: selectorString with: valueString

	^ driver handleResponse:
			(driver httpPost: (self baseElementURL addPathSegment: 'elements')
				data: (BPPlatform current data: (Dictionary new at: 'using' put: selectorString; at: 'value' put: valueString; yourself) asJson))
		onSuccess: [ :result |
			(result at: 'value') collect: [ :e | BPWebElement driver: driver elementID: (e at: 'ELEMENT') ]
		].! !

!BPWebElement methodsFor: 'misc' stamp: 'JohanBrichau 5/23/2012 16:31'!
findElementsByCSSSelector: cssSelectorString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'css selector' with: cssSelectorString! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 4/18/2012 13:42'!
findElementsByClassName: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'class name' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'JohanBrichau 8/14/2012 19:57'!
findElementsByPartialLinkText: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'partial link text' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 4/18/2012 11:10'!
findElementsByTagName: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'tag name' with: nameString
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 5/30/2012 16:04'!
findElementsByXPath: xpathString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#findElements(org.openqa.selenium.By)
	"
	
	^ self findElementsBy: 'xpath' with: xpathString
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:53'!
getAttribute: nameString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#getAttribute(java.lang.String)
	"
	
	self flag: 'Check whether this implementation matches the description of the original Java method'.
	
	^ driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'attribute'; addPathSegment: nameString))
		onSuccess: [ :result | result at: 'value' ]

	! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:53'!
getLocation

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#getLocation()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'location'))
		onSuccess: [ :result | ((result at: 'value') at: 'x') @ ((result at: 'value') at: 'y') ]
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:53'!
getSize

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#getSize()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'size'))
		onSuccess: [ :result | ((result at: 'value') at: 'width') @ ((result at: 'value') at: 'height') ]
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:54'!
getText

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#getText()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'text'))
		onSuccess: [ :result | (result at: 'value') ]
! !

!BPWebElement methodsFor: 'comparing' stamp: 'KrisGybels 2/6/2014 14:56'!
hash

	"In #= we need to ask the remote driver to compare the elements, but we can't ask it for #hash since the wire protocol
		does not define an operation for that. We therefore resort to returning a constant hash:"
	
	^ 0! !

!BPWebElement methodsFor: 'initialize-release' stamp: 'KrisGybels 4/6/2012 12:32'!
initWithDriver: initialDriver elementID: initialElementID

	super initialize.
	driver := initialDriver.
	elementID := initialElementID.
! !

!BPWebElement methodsFor: 'misc' stamp: 'KrisGybels 7/4/2012 10:54'!
isDisplayed

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#isDisplayed()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseElementURL addPathSegment: 'displayed'))
		onSuccess: [ :result | (result at: 'value') ]
! !

!BPWebElement methodsFor: 'json' stamp: 'KrisGybels 4/13/2012 09:37'!
jsonOn: stream

	(Dictionary new at: 'ELEMENT' put: elementID; yourself) jsonOn: stream! !

!BPWebElement methodsFor: 'events' stamp: 'StephanEggermont 10/1/2012 19:22'!
sendKeys: keyString

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebElement.html#sendKeys(java.lang.CharSequence...)
	"
	
	| keyArray |
	self flag: 'This may need to take something other than a string, to be able to send special key presses (like shift, command etc.)'.
	
	keyArray := keyString collect: [ :char | char asString ] as: Array.
	driver handleResponse:
		(driver httpPost: (self baseElementURL addPathSegment: 'value')
			data: (BPPlatform current data: (Dictionary new at: 'value' put: keyArray; yourself) asJson))

! !

BPObject subclass: #BPWindow
	instanceVariableNames: 'driver handle'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!BPWindow class methodsFor: 'instance creation' stamp: 'KrisGybels 11/6/2012 10:23'!
withDriver: driver handle: handle

	^ self basicNew initWithDriver: driver handle: handle! !

!BPWindow methodsFor: 'private' stamp: 'KrisGybels 11/6/2012 10:57'!
baseURL

	^ driver baseSessionURL addPathSegment: 'window'; addPathSegment: handle! !

!BPWindow methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 11:53'!
getPosition

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.Window.html#getPosition()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseURL addPathSegment: 'position'))
		onSuccess: [ :result | Point x: ((result at: 'value') at: 'x') y: ((result at: 'value') at: 'y') ]! !

!BPWindow methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 11:54'!
getSize

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.Window.html#getSize()
	"
	
	^ driver handleResponse: (driver httpGet: (self baseURL addPathSegment: 'size'))
		onSuccess: [ :result | Point x: ((result at: 'value') at: 'width') y: ((result at: 'value') at: 'height') ]! !

!BPWindow methodsFor: 'initialize-release' stamp: 'KrisGybels 11/6/2012 10:23'!
initWithDriver: initialDriver handle: initialHandle

	self initialize.
	driver := initialDriver.
	handle := initialHandle.
	! !

!BPWindow methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 10:57'!
setPosition: point

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.Window.html#setPosition(org.openqa.selenium.Point)
	"
	
	driver handleResponse:
		(driver httpPost: (self baseURL addPathSegment: 'position')
			data: (BPPlatform current data: (Dictionary new at: 'x' put: point x; at: 'y' put: point y; yourself) asJson))! !

!BPWindow methodsFor: 'misc' stamp: 'KrisGybels 11/6/2012 10:57'!
setSize: point

	"
		http://selenium.googlecode.com/svn/trunk/docs/api/java/org/openqa/selenium/WebDriver.Window.html#setSize(org.openqa.selenium.Dimension)
	"
	
	driver handleResponse:
		(driver httpPost: (self baseURL addPathSegment: 'size')
			data: (BPPlatform current data: (Dictionary new at: 'width' put: point x; at: 'height' put: point y; yourself) asJson))! !

Error subclass: #BPElementNotVisibleException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

Error subclass: #BPInvalidSelectorException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

Error subclass: #BPNoSuchElementException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

Error subclass: #BPStaleElementReferenceException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

Error subclass: #BPUnknownServerException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

Error subclass: #BPUnsupportedCommandException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Parasol-Core'!

!String methodsFor: '*Parasol-Core' stamp: 'KrisGybels 4/10/2012 08:49'!
withoutTrailingZeroes

	| last |
	last := self findLast: [ :c | c asciiValue ~= 0 ].
	last = 0 ifTrue: [ ^ '' ].
	^ self copyFrom: 1 to: last
! !
